AppleWatchHeartRate class

Heart rate data from the Apple Watch, sampled via HealthKit.

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.none, includeIfNull: false)

Constructors

AppleWatchHeartRate({String? deviceId, DateTime? timestamp, String? label, double hr = 0})
AppleWatchHeartRate.fromJson(Map<String, dynamic> json)
factory
AppleWatchHeartRate.fromRecord(Map<String, dynamic> record)
Create an AppleWatchHeartRate from an AWARE ios_watch_heart_rate record.

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
dataType → DataType
The type of this data as a DataType.
no setterinherited
deviceId String?
The AWARE device id of the Apple Watch which collected this data.
getter/setter pairinherited
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hr double
Heart rate in beats per minute (BPM).
getter/setter pair
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setteroverride
label String?
The AWARE data label of this data, if any.
getter/setter pairinherited
recordId String?
Stable identifier of the source record, if available.
no setterinherited
rowId int?
The id of the record in the local database on the Apple Watch.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The timestamp of this data, as set by the Apple Watch.
getter/setter pairinherited

Methods

equivalentTo(Data other) bool
Is this data equivalent to other?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited