AppleWatchRecords class
A batch of records transferred from the Apple Watch to the phone.
The watch exports its local database in pages, compresses each page, and transfers it to the phone as a file. One AppleWatchRecords is the content of one such file, i.e. all records from one table in one chunk.
Constructors
-
AppleWatchRecords({required String table, required int chunkIndex, required int totalChunks, required List<
Map< records})String, dynamic> > - AppleWatchRecords.fromMap(Map map)
-
factory
Properties
- chunkIndex → int
-
The 1-based index of this chunk in the transfer session.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
records
→ List<
Map< String, dynamic> > -
The records in this chunk, as raw AWARE rows.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → String
-
The AWARE table these records come from. See AppleWatchTable.
final
- totalChunks → int
-
The total number of chunks in this transfer session for this table.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited