AppleWatchStatus class
The runtime status of the connection between the phone and the Apple Watch.
Constructors
- AppleWatchStatus({bool isSupported = false, bool isPaired = false, bool isWatchAppInstalled = false, bool isReachable = false, bool isCollectingData = false, String activationState = 'notActivated', int outstandingFileTransferCount = 0, String? phoneDeviceId, String? watchDeviceId, DateTime? lastMessageAt, DateTime? lastFileTransferAt, String? lastError})
- AppleWatchStatus.fromMap(Map map)
-
factory
Properties
- activationState → String
-
The activation state of the
WCSession-notActivated,inactive, oractivated.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isAvailable → bool
-
Is the watch ready to collect data, i.e. paired with this phone and with
the companion watch app installed?
no setter
- isCollectingData → bool
-
Is the watch app currently collecting data?
final
- isPaired → bool
-
Is an Apple Watch paired with this phone?
final
- isReachable → bool
-
Is the watch app reachable right now?
final
- isSupported → bool
-
Is
WatchConnectivitysupported on this phone? Always false on Android and on iPads.final - isWatchAppInstalled → bool
-
Is the companion watch app installed on the paired Apple Watch?
final
- lastError → String?
-
The last communication error, if any.
final
- lastFileTransferAt → DateTime?
-
When the phone last received a file from the watch.
final
- lastMessageAt → DateTime?
-
When the phone last exchanged a message with the watch.
final
- outstandingFileTransferCount → int
-
The number of file transfers from the watch which have not yet completed.
final
- phoneDeviceId → String?
-
The AWARE device id of this phone.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- watchDeviceId → String?
-
The AWARE device id of the paired watch, if it has been exchanged.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited