isCollectingData property
Is the watch app currently collecting data?
This is based on the last status message sent by the watch app, and is therefore only known after the watch app has been started at least once.
Implementation
final bool isCollectingData;